==> de.flapdoodle.eval-1.0.1-sources.jar: de/flapdoodle/eval/core/tree/EvalFailedWithException.java <==
/*
 * Copyright (C) 2023
 *   Michael Mosmann <michael@mosmann.de>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.eval.core.tree;

import de.flapdoodle.eval.core.exceptions.EvaluationException;
import org.immutables.value.Value;

import java.util.Optional;

@Value.Immutable
public abstract class EvalFailedWithException {
	public abstract EvaluationException exception();

	public static EvalFailedWithException of(EvaluationException exception) {
		return ImmutableEvalFailedWithException.builder()
			.exception(exception)
			.build();
	}

	public static EvaluableExceptionMapper mapper() {
		return new EvaluableExceptionMapper() {
			@Override
			public Object map(EvaluationException ex) {
				return EvalFailedWithException.of(ex);
			}
			@Override
			public Optional<EvaluationException> match(Object value) {
				return value instanceof EvalFailedWithException
					? Optional.of(((EvalFailedWithException) value).exception())
					: Optional.empty();
			}
		};
	}
}

==> de.flapdoodle.eval-1.1.0-sources.jar: de/flapdoodle/eval/core/tree/EvalFailedWithException.java <==
/*
 * Copyright (C) 2023
 *   Michael Mosmann <michael@mosmann.de>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.eval.core.tree;

import de.flapdoodle.eval.core.evaluables.Evaluated;
import de.flapdoodle.eval.core.exceptions.EvaluationException;
import org.immutables.value.Value;

import java.util.Optional;

@Value.Immutable
public abstract class EvalFailedWithException {
	public abstract EvaluationException exception();

	public static EvalFailedWithException of(EvaluationException exception) {
		return ImmutableEvalFailedWithException.builder()
			.exception(exception)
			.build();
	}

	public static EvaluableExceptionMapper mapper() {
		return new EvaluableExceptionMapper() {
			@Override
			public Object map(EvaluationException ex) {
				return EvalFailedWithException.of(ex);
			}
			@Override
			public Optional<EvaluationException> match(Evaluated<?> value) {
				return value.wrapped() instanceof EvalFailedWithException
					? Optional.of(((EvalFailedWithException) value.wrapped()).exception())
					: Optional.empty();
			}
		};
	}
}
